using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Drawing.Imaging;

namespace PictureQuality
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btnOpen_Click(object sender, EventArgs e)
        {
            if (fbdOpen.ShowDialog() == DialogResult.OK)
            {
                // Clear any previous items in the list
                lstPhotos.Items.Clear();
                // Run a loop through all the files in the directory at the selected path
                foreach(string Filename in Directory.GetFiles(fbdOpen.SelectedPath))
                {
                    // We'll create a new FileInfo object from the file path
                    FileInfo fiPicture = new FileInfo(Filename);
                    // If it's a JPEG file
                    if (fiPicture.Extension.ToLower() == ".jpeg" || fiPicture.Extension.ToLower() == ".jpg")
                    {
                        // Add it to the list of files
                        lstPhotos.Items.Add(Filename);
                    }
                }
            }
            // We want the ProgressBar to have the same maximum value as the number of pictures to resize
            prgReduce.Maximum = lstPhotos.Items.Count;
        }

        private void btnReduce_Click(object sender, EventArgs e)
        {
            // Reset the progress bar
            prgReduce.Value = 0;
            // Show the FolderBrowserDialog where the user selects where to save the files
            if (fbdSave.ShowDialog() == DialogResult.OK)
            {
                // We will store the correct image codec in this object
                ImageCodecInfo iciJpegCodec = null;
                // This will specify the image quality to the encoder
                EncoderParameter epQuality = new EncoderParameter(System.Drawing.Imaging.Encoder.Quality, (int)numQual.Value);
                // Get all image codecs that are available
                ImageCodecInfo[] iciCodecs = ImageCodecInfo.GetImageEncoders();
                // Store the quality parameter in the list of encoder parameters
                EncoderParameters epParameters = new EncoderParameters(1);
                epParameters.Param[0] = epQuality;

                // Loop through all the image codecs
                for (int i = 0; i < iciCodecs.Length; i++)
                {
                    // Until the one that we are interested in is found, which is image/jpeg
                    if (iciCodecs[i].MimeType == "image/jpeg")
                    {
                        iciJpegCodec = iciCodecs[i];
                        break;
                    }
                }

                // Loop through the files in the list
                foreach (string strFile in lstPhotos.Items)
                {
                    // Take another step on the progress bar
                    prgReduce.PerformStep();

                    // Create a new Image object from the current file
                    Image newImage = Image.FromFile(strFile);

                    // Get the file information again, this time we want to find out the extension
                    FileInfo fiPicture = new FileInfo(strFile);
                    // Save the new file at the selected path with the specified encoder parameters, and reuse the same file name
                    newImage.Save(fbdSave.SelectedPath + "\\" + fiPicture.Name, iciJpegCodec, epParameters);
                }
            }
            // Open the folder containing the new items
            System.Diagnostics.Process.Start(fbdSave.SelectedPath.ToString());
        }
    }
}